@@ -42,7 +42,7 @@ SaveLocation::SaveLocation(QWidget *parent)
     connect(m_ui->u_urlRequester, &KUrlRequester::textChanged, this, &SaveLocation::updateGui);
     connect(m_ui->u_imgPrefix, &QLineEdit::textChanged, this, &SaveLocation::updateGui);
 #if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
-    connect(u_imgFormat, static_cast<void (QComboBox::*)(const QString &)>(&QComboBox::activated), this, &SaveLocation::updateGui);
+    connect(m_ui->u_imgFormat, static_cast<void (QComboBox::*)(const QString &)>(&QComboBox::activated), this, &SaveLocation::updateGui);
 #else
     connect(m_ui->u_imgFormat, static_cast<void (QComboBox::*)(const QString &)>(&QComboBox::textActivated), this, &SaveLocation::updateGui);
 #endif
@@ -58,7 +58,7 @@ void SaveLocation::updateGui()
     if (sender() != m_ui->u_numStartFrom) {
         m_ui->u_numStartFrom->setValue(1); // Reset the counter whenever the directory or the prefix is changed
     }
-    const QString name = QString::fromLatin1("%1%2.%3")
+    const QString name = QStringLiteral("%1%2.%3")
     .arg(m_ui->u_imgPrefix->text())
     .arg(m_ui->u_numStartFrom->value(), 4, 10, QLatin1Char('0'))
     .arg(m_ui->u_imgFormat->currentText());
