@@ -43,6 +43,7 @@
 #include <QCloseEvent>
 #include <QProgressBar>
 
+#include <KAboutData>
 #include <KAboutApplicationDialog>
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -53,6 +54,7 @@
 #include <KSharedConfig>
 #include <KConfigGroup>
 #include <KHelpClient>
+#include <kio_version.h>
 
 #include <skanlite_debug.h>
 
@@ -60,7 +62,6 @@
 
 Skanlite::Skanlite(const QString &device, QWidget *parent)
     : QDialog(parent)
-    , m_aboutData(nullptr)
     , m_dbusInterface(this)
 {
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
@@ -71,12 +72,12 @@ Skanlite::Skanlite(const QString &device, QWidget *parent)
     QPushButton *btnAbout = dlgButtonBoxBottom->addButton(i18n("About"), QDialogButtonBox::ButtonRole::ActionRole);
     // was "User1":
     QPushButton *btnSettings = dlgButtonBoxBottom->addButton(i18n("Settings"), QDialogButtonBox::ButtonRole::ActionRole);
-    btnSettings->setIcon(QIcon::fromTheme(QLatin1String("configure")));
+    btnSettings->setIcon(QIcon::fromTheme(QStringLiteral("configure")));
 
     m_firstImage = true;
 
     m_ksanew = new KSaneIface::KSaneWidget(this);
-    connect(m_ksanew, &KSaneWidget::imageReady, this, &Skanlite::imageReady);
+    connect(m_ksanew, &KSaneWidget::scannedImageReady, this, &Skanlite::imageReady);
     connect(m_ksanew, &KSaneWidget::availableDevices, this, &Skanlite::availableDevices);
     connect(m_ksanew, &KSaneWidget::userMessage, this, &Skanlite::alertUser);
     connect(m_ksanew, &KSaneWidget::buttonPressed, this, &Skanlite::buttonPressed);
@@ -123,13 +124,13 @@ Skanlite::Skanlite(const QString &device, QWidget *parent)
 
         QWidget *settingsWidget = new QWidget(m_settingsDialog);
         m_settingsUi.setupUi(settingsWidget);
-        m_settingsUi.revertOptions->setIcon(QIcon::fromTheme(QLatin1String("edit-undo")));
+        m_settingsUi.revertOptions->setIcon(QIcon::fromTheme(QStringLiteral("edit-undo")));
         m_saveLocation = new SaveLocation(this);
 
         // add the supported image types
         const QList<QByteArray> tmpList = QImageWriter::supportedMimeTypes();
         m_filterList.clear();
-        foreach (auto ba, tmpList) {
+        for (const auto &ba : tmpList) {
             if (ba.isEmpty()) {
                 continue;
             }
@@ -139,26 +140,30 @@ Skanlite::Skanlite(const QString &device, QWidget *parent)
         qCDebug(SKANLITE_LOG) << m_filterList;
 
         // Put first class citizens at first place
-        m_filterList.removeAll(QLatin1String("image/jpeg"));
-        m_filterList.removeAll(QLatin1String("image/tiff"));
-        m_filterList.removeAll(QLatin1String("image/png"));
-        m_filterList.insert(0, QLatin1String("image/png"));
-        m_filterList.insert(1, QLatin1String("image/jpeg"));
-        m_filterList.insert(2, QLatin1String("image/tiff"));
+        m_filterList.removeAll(QStringLiteral("image/jpeg"));
+        m_filterList.removeAll(QStringLiteral("image/tiff"));
+        m_filterList.removeAll(QStringLiteral("image/png"));
+        m_filterList.insert(0, QStringLiteral("image/png"));
+        m_filterList.insert(1, QStringLiteral("image/jpeg"));
+        m_filterList.insert(2, QStringLiteral("image/tiff"));
 
-        m_filter16BitList << QLatin1String("image/png");
-        //m_filter16BitList << QLatin1String("image/tiff");
+        m_filter16BitList << QStringLiteral("image/png");
+        m_filter16BitList << QStringLiteral("image/tiff");
 
         // fill m_filterList (...) and m_typeList (list of file suffixes)
-        foreach (QString mimeStr, m_filterList) {
-            QMimeType mimeType = QMimeDatabase().mimeTypeForName(mimeStr);
-            m_filterList.append(mimeType.name());
+        {
+            QStringList namedMimeTypes;
+            for (const QString &mimeStr : qAsConst(m_filterList)) {
+                QMimeType mimeType = QMimeDatabase().mimeTypeForName(mimeStr);
+                namedMimeTypes.append(mimeType.name());
 
-            QStringList fileSuffixes = mimeType.suffixes();
+                QStringList fileSuffixes = mimeType.suffixes();
 
-            if (fileSuffixes.size() > 0) {
-                m_typeList << fileSuffixes.first();
+                if (fileSuffixes.size() > 0) {
+                    m_typeList << fileSuffixes.first();
+                }
             }
+            m_filterList << std::move(namedMimeTypes);
         }
 
         m_settingsUi.imgFormat->addItems(m_typeList);
@@ -197,8 +202,8 @@ Skanlite::Skanlite(const QString &device, QWidget *parent)
             exit(1);
         }
         else {
-            setWindowTitle(i18nc("@title:window %1 = scanner maker, %2 = scanner model", "%1 %2 - Skanlite", m_ksanew->make(), m_ksanew->model()));
-            m_deviceName = QString::fromLatin1("%1:%2").arg(m_ksanew->make(), m_ksanew->model());
+            setWindowTitle(i18nc("@title:window %1 = scanner maker, %2 = scanner model", "%1 %2 - Skanlite", m_ksanew->deviceVendor(), m_ksanew->deviceModel()));
+            m_deviceName = QStringLiteral("%1:%2").arg(m_ksanew->deviceVendor(), m_ksanew->deviceModel());
         }
     }
     else {
@@ -217,8 +222,6 @@ Skanlite::Skanlite(const QString &device, QWidget *parent)
     // load saved options
     loadScannerOptions();
 
-    m_ksanew->initGetDeviceList();
-
     m_firstImage = true;
 
     if (m_dbusInterface.setupDBusInterface()) {
@@ -250,12 +253,7 @@ Skanlite::Skanlite(const QString &device, QWidget *parent)
 
 void Skanlite::showHelp()
 {
-    KHelpClient::invokeHelp(QLatin1String("index"), QLatin1String("skanlite"));
-}
-
-void Skanlite::setAboutData(KAboutData *aboutData)
-{
-    m_aboutData = aboutData;
+    KHelpClient::invokeHelp(QStringLiteral("index"), QStringLiteral("skanlite"));
 }
 
 void Skanlite::closeEvent(QCloseEvent *event)
@@ -365,18 +363,12 @@ void Skanlite::showSettingsDialog(void)
     }
 }
 
-void Skanlite::imageReady(QByteArray &data, int w, int h, int bpl, int f)
+void Skanlite::imageReady(const QImage &image)
 {
     // save the image data
-    m_data = data;
-    m_width = w;
-    m_height = h;
-    m_bytesPerLine = bpl;
-    m_format = f;
-
     if (m_settingsUi.showB4Save->isChecked() == true) {
         /* copy the image data into m_img and show it*/
-        m_img = m_ksanew->toQImageSilent(data, w, h, bpl, (KSaneIface::KSaneWidget::ImageFormat)f);
+        m_img = image;
         m_showImgDialog->setQImage(&m_img);
         m_showImgDialog->zoom2Fit();
         m_showImgDialog->exec();
@@ -396,7 +388,11 @@ bool urlExists(const QUrl& url)
         }
     }
     else {
-        KIO::StatJob *statJob = KIO::statDetails(url, KIO::StatJob::DestinationSide);
+#if KIO_VERSION < QT_VERSION_CHECK(5, 69, 0)
+        KIO::StatJob *statJob = KIO::stat(url, KIO::StatJob::DestinationSide, 0);
+#else
+        KIO::StatJob *statJob = KIO::statDetails(url, KIO::StatJob::DestinationSide, KIO::StatNoDetails);
+#endif
         KJobWidgets::setWindow(statJob, QApplication::activeWindow());
         if (!statJob->exec()) {
             return false;
@@ -434,15 +430,15 @@ void Skanlite::saveImage()
     QString imgFormat = m_saveLocation->imageFormat().toLower();
     int fileNumber = m_saveLocation->startNumber();
     QStringList filterList = m_filterList;
-    bool enforceSavingAsPng16bit = false;
-    if ((m_format == KSaneIface::KSaneWidget::FormatRGB_16_C) ||
-        (m_format == KSaneIface::KSaneWidget::FormatGrayScale16))
+
+    if ((m_img.format() == QImage::Format_Grayscale16) ||
+        (m_img.format() == QImage::Format_RGBX64))
     {
         filterList = m_filter16BitList;
-        enforceSavingAsPng16bit = true;
-        if (imgFormat != QLatin1String("png")) {
-            imgFormat = QLatin1String("png");
-            KMessageBox::information(this, i18n("The image will be saved in the PNG format, as Skanlite only supports saving 16 bit color images in the PNG format."));
+        if (imgFormat != QLatin1String("png") && imgFormat != QLatin1String("tif")
+            && imgFormat != QLatin1String("tiff")) {
+            imgFormat = QStringLiteral("png");
+            KMessageBox::information(this, i18n("The image will be saved in the PNG format, as the selected image type does not support saving 16 bit color images."));
         }
     }
 
@@ -450,7 +446,7 @@ void Skanlite::saveImage()
     QUrl fileUrl;
     QString fname;
     for (int i = fileNumber; i <= m_saveLocation->startNumberMax(); ++i) {
-        fname = QString::fromLatin1("%1%2.%3")
+        fname = QStringLiteral("%1%2.%3")
                 .arg(prefix)
                 .arg(i, 4, 10, QLatin1Char('0'))
                 .arg(imgFormat);
@@ -499,7 +495,7 @@ void Skanlite::saveImage()
     QString suffix = QFileInfo(fileUrl.fileName()).suffix();
     QString fileFormat;
     if (suffix.isEmpty()) {
-        fileFormat = QLatin1String("png");
+        fileFormat = QStringLiteral("png");
     }
 
     if (!fileUrl.isLocalFile()) {
@@ -520,14 +516,12 @@ void Skanlite::saveImage()
     SkanliteImageSaver *imageSaver = new SkanliteImageSaver(this);
     connect(imageSaver, &SkanliteImageSaver::imageSaved, this, &Skanlite::imageSaved);
 
-    // Save
-    if (enforceSavingAsPng16bit) {
-        imageSaver->save16BitPng(fileUrl, localName, m_data, m_width, m_height, m_bytesPerLine, (int)m_ksanew->currentDPI(), m_format, fileFormat, quality);
-    } else {
-        imageSaver->saveQImage(fileUrl, localName, m_data, m_width, m_height, m_bytesPerLine, (int)m_ksanew->currentDPI(), m_format, fileFormat, quality);
-    }
+    imageSaver->saveQImage(fileUrl, localName, m_img, static_cast<int>(m_ksanew->currentDPI()), fileFormat, quality);
 
+    m_showImgDialog->blockSignals(true);
     m_showImgDialog->close(); // calling close() on a closed window does nothing.
+    // NOTE we need to block the signals since close() will emit rejected()
+    m_showImgDialog->blockSignals(false);
 
     // Disable parts of the interface and indicate that we are saving the image
     m_currentSaveUrl = fileUrl;
@@ -585,11 +579,11 @@ void Skanlite::imageSaved(const QUrl &fileUrl, const QString &localName, bool su
             KMessageBox::sorry(nullptr, i18n("Failed to upload image"));
         }
         else {
-            emit m_dbusInterface.imageSaved(fileUrl.toString());
+            Q_EMIT m_dbusInterface.imageSaved(fileUrl.toString());
         }
     }
     else {
-        emit m_dbusInterface.imageSaved(localName);
+        Q_EMIT m_dbusInterface.imageSaved(localName);
     }
     m_ksanew->setDisabled(false);
     m_saveUpdateTimer.stop();
@@ -603,7 +597,7 @@ void Skanlite::imageSaved(const QUrl &fileUrl, const QString &localName, bool su
 
 void Skanlite::showAboutDialog(void)
 {
-    KAboutApplicationDialog(*m_aboutData).exec();
+    KAboutApplicationDialog(KAboutData::applicationData()).exec();
 }
 
 void writeScannerOptions(const QString &groupName, const QMap <QString, QString> &opts)
@@ -632,10 +626,10 @@ void Skanlite::saveScannerOptions()
         return;
     }
 
-    KConfigGroup options(KSharedConfig::openConfig(), QString::fromLatin1("Options For %1").arg(m_deviceName));
+    KConfigGroup options(KSharedConfig::openConfig(), QStringLiteral("Options For %1").arg(m_deviceName));
     QMap <QString, QString> opts;
     m_ksanew->getOptVals(opts);
-    writeScannerOptions(QString::fromLatin1("Options For %1").arg(m_deviceName), opts);
+    writeScannerOptions(QStringLiteral("Options For %1").arg(m_deviceName), opts);
 }
 
 void Skanlite::defaultScannerOptions()
@@ -666,14 +660,14 @@ void Skanlite::loadScannerOptions()
     }
 
     QMap <QString, QString> opts;
-    readScannerOptions(QString::fromLatin1("Options For %1").arg(m_deviceName), opts);
+    readScannerOptions(QStringLiteral("Options For %1").arg(m_deviceName), opts);
     applyScannerOptions(opts);
 }
 
 void Skanlite::availableDevices(const QList<KSaneWidget::DeviceInfo> &deviceList)
 {
-    for (int i = 0; i < deviceList.size(); ++i) {
-        qCDebug(SKANLITE_LOG) << deviceList.at(i).name;
+    for (const KSaneWidget::DeviceInfo &device : deviceList) {
+        qCDebug(SKANLITE_LOG) << device.name;
     }
 }
 
@@ -681,10 +675,10 @@ void Skanlite::alertUser(int type, const QString &strStatus)
 {
     switch (type) {
     case KSaneWidget::ErrorGeneral:
-        KMessageBox::sorry(nullptr, strStatus, QLatin1String("Skanlite Test"));
+        KMessageBox::sorry(nullptr, strStatus, QStringLiteral("Skanlite Test"));
         break;
     default:
-        KMessageBox::information(nullptr, strStatus, QLatin1String("Skanlite Test"));
+        KMessageBox::information(nullptr, strStatus, QStringLiteral("Skanlite Test"));
     }
 }
 
@@ -708,7 +702,7 @@ QStringList serializeScannerOptions(const QMap<QString, QString> &opts)
 
 void deserializeScannerOptions(const QStringList &settings, QMap<QString, QString> &opts)
 {
-    foreach (QString s, settings) {
+    for (const QString &s : settings) {
         int i = s.lastIndexOf(QLatin1Char('='));
         opts[s.left(i)] = s.right(s.length()-i-1);
     }
@@ -719,14 +713,14 @@ static const auto selectionSettings = { QLatin1String("tl-x"), QLatin1String("tl
 
 void filterSelectionSettings(QMap<QString, QString> &opts)
 {
-    foreach (QString s, selectionSettings) {
+    for (const auto &s : selectionSettings) {
         opts.remove(s);
     }
 }
 
 bool containsSelectionSettings(const QMap<QString, QString> &opts)
 {
-    foreach (QString s, selectionSettings) {
+    for (const auto &s : selectionSettings) {
         if (opts.contains(s)) {
             return true;
         }
@@ -803,7 +797,7 @@ void Skanlite::getSelection()
     m_ksanew->getOptVals(opts);
 
     QStringList reply;
-    foreach ( QString key, selectionSettings ) {
+    for (const auto &key : selectionSettings ) {
         if (opts.contains(key)) {
             reply.append(key + QLatin1Char('=') + opts[key]);
         }
